@@ -104,6 +104,11 @@
         <source>Compress destination</source>
         <translation type="unfinished">Destino de compresión</translation>
     </message>
+    <message>
+        <location filename="../home.cpp" line="10"/>
+        <source>Extract destination</source>
+        <translation type="unfinished">Destino de extracción</translation>
+    </message>
 </context>
 <context>
     <name>Clipboard</name>
@@ -711,4 +716,83 @@
         <translation type="unfinished">Cerrar</translation>
     </message>
 </context>
+<context>
+    <name>Unzip</name>
+    <message>
+        <location filename="../unzip.cpp" line="10"/>
+        <source>Extract files</source>
+        <translation type="unfinished">Extraer archivos</translation>
+    </message>
+    <message>
+        <location filename="../unzip.cpp" line="10"/>
+        <source>Cancel</source>
+        <translation type="unfinished">Cancelar</translation>
+    </message>
+    <message>
+        <location filename="../unzip.cpp" line="10"/>
+        <source>Not enough space to proceed.</source>
+        <translation type="unfinished">No hay suficiente espacio para proceder.</translation>
+    </message>
+    <message>
+        <location filename="../unzip.cpp" line="10"/>
+        <source>You don't have permissions to proceed.</source>
+        <translation type="unfinished">No tiene permisos para proceder.</translation>
+    </message>
+</context>
+<context>
+    <name>UnzipDlg</name>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Extract</source>
+        <translation type="unfinished">Extraer</translation>
+    </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Destination folder</source>
+        <translation type="unfinished">Carpeta destino</translation>
+    </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Keep existing files</source>
+        <translation type="unfinished">Mantener archivos existentes</translation>
+    </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Accept</source>
+        <translation type="unfinished">Aceptar</translation>
+    </message>
+    <message>
+        <location filename="../unzipdlg.cpp" line="10"/>
+        <source>Cancel</source>
+        <translation type="unfinished">Cancelar</translation>
+    </message>
+</context>
+<context>
+    <name>Extract</name>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Extracting</source>
+        <translation type="unfinished">Extrayendo</translation>
+    </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Extracting %1...</source>
+        <translation type="unfinished">Extrayendo %1...</translation>
+    </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Operation finished.</source>
+        <translation type="unfinished">Operación terminada.</translation>
+    </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Cancel</source>
+        <translation type="unfinished">Cancelar</translation>
+    </message>
+    <message>
+        <location filename="../extract.cpp" line="10"/>
+        <source>Close</source>
+        <translation type="unfinished">Cerrar</translation>
+    </message>
+</context>
 </TS>
